@@ -11,7 +11,7 @@ from .common import check_text_files
 from .common import perform_regression_check
 
 if TYPE_CHECKING:
-    from pytest_datadir import LazyDataDir
+    from pytest_datadir.plugin import LazyDataDir
 
 
 class FileRegressionFixture:
