@@ -4,22 +4,23 @@ from textwrap import dedent
 import pytest
 import yaml
 
+from pytest_regressions.data_regression import DataRegressionFixture
 from pytest_regressions.testing import check_regression_fixture_workflow
 
 
-def test_example(data_regression):
+def test_example(data_regression: DataRegressionFixture) -> None:
     """Basic example"""
     contents = {"contents": "Foo", "value": 11}
     data_regression.check(contents)
 
 
-def test_basename(data_regression):
+def test_basename(data_regression: DataRegressionFixture) -> None:
     """Basic example using basename parameter"""
     contents = {"contents": "Foo", "value": 11}
     data_regression.check(contents, basename="case.normal")
 
 
-def test_integer_keys(data_regression):
+def test_integer_keys(data_regression: DataRegressionFixture) -> None:
     """Test that integer keys are supported in data dictionaries."""
     contents = {
         1: "first",
@@ -30,7 +31,7 @@ def test_integer_keys(data_regression):
     data_regression.check(contents)
 
 
-def test_custom_object(data_regression):
+def test_custom_object(data_regression: DataRegressionFixture) -> None:
     """Basic example where we register a custom conversion to dump objects"""
 
     class Scalar:
@@ -50,7 +51,7 @@ def test_custom_object(data_regression):
     data_regression.check(contents)
 
 
-def test_round_digits(data_regression):
+def test_round_digits(data_regression: DataRegressionFixture) -> None:
     """Example including float numbers and check rounding capabilities."""
     contents = {
         "content": {"value1": "toto", "value": 1.123456789},
@@ -74,7 +75,7 @@ def test_usage_workflow(pytester, monkeypatch):
     )
     source = """
         import sys
-        def test_1(data_regression):
+        def test_1(data_regression) -> None:
             contents = sys.testing_get_data()
             data_regression.check(contents)
     """
@@ -109,7 +110,7 @@ def test_data_regression_full_path(pytester, tmp_path):
     assert not fullpath.is_file()
 
     source = """
-        def test(data_regression):
+        def test(data_regression) -> None:
             contents = {'data': [1, 2]}
             data_regression.check(contents, fullpath=%s)
     """ % (
@@ -138,7 +139,7 @@ def test_data_regression_no_aliases(pytester):
     This test makes sure data regression never uses aliases when dumping expected file to YAML.
     """
     source = """
-        def test(data_regression):
+        def test(data_regression) -> None:
             red = (255, 0, 0)
             green = (0, 255, 0)
             blue = (0, 0, 255)
@@ -195,7 +196,7 @@ def test_not_create_file_on_error(pytester):
     """Basic example where we serializing the object should throw an error and should not create the file"""
 
     source = """
-        def test(data_regression):
+        def test(data_regression) -> None:
             class Scalar:
                 def __init__(self, value, unit):
                     self.value = value
@@ -215,14 +216,14 @@ def test_not_create_file_on_error(pytester):
 
 def test_regen_all(pytester, tmp_path):
     source = """
-        def test_1(data_regression):
+        def test_1(data_regression) -> None:
             contents = {"contents": "Foo", "value": 11}
             data_regression.check(contents, basename="test_1_a")
 
             contents = {"contents": "Bar", "value": 12}
             data_regression.check(contents, basename="test_1_b")
 
-        def test_2(data_regression):
+        def test_2(data_regression) -> None:
             contents = {"contents": "Baz", "value": 33}
             data_regression.check(contents, basename="test_2_a")
 
